==> org.opennms.features.request-tracker-1.12.7-20140528.151850-41-sources.jar: org/opennms/netmgt/rt/RtConfigDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2010-2012 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.rt;

import java.io.IOException;
import java.util.List;

public interface RtConfigDao {

    public String getUsername();
    public String getPassword();
    public String getQueue();
    public List<String> getValidClosedStatus();
    public List<Integer> getValidOpenStatus();
    public List<String> getValidCancelledStatus();
    public String getOpenStatus();
    public String getClosedStatus();
    public String getCancelledStatus();
    public String getRequestor();
    public String getBaseURL();
    public int getTimeout();
    public int getRetry();

    public void save() throws IOException;
}

==> org.opennms.features.request-tracker-1.13.0-20131211.225246-386-sources.jar: org/opennms/netmgt/rt/RtConfigDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2010-2012 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.rt;

import java.io.IOException;
import java.util.List;

public interface RtConfigDao {

    public String getUsername();
    public String getPassword();
    public String getQueue();
    public List<String> getValidClosedStatus();
    public List<String> getValidOpenStatus();
    public List<String> getValidCancelledStatus();
    public String getOpenStatus();
    public String getClosedStatus();
    public String getCancelledStatus();
    public String getRequestor();
    public String getBaseURL();
    public int getTimeout();
    public int getRetry();

    public void save() throws IOException;
}
